from sqlalchemy import create_engine


class Config(object):
    def __init__(self):
        # Snowflake
        self.snowflake_username = None
        self.snowflake_password = None
        self.snowflake_account = None
        self.snowflake_role = None
        self.snowflake_database = None

        # Email
        self.SMTP_SERVER = "10.1.199.125"
        self.FROM_EMAIL = "dmk@chewy.com"
        self.REC_LIST = None

        self.SLACK_SUCCESS = '''mkt-etl-success-alert-aaaags6ughywknj64qawvq2qpy@chewy.org.slack.com'''
        self.SLACK_FAILURE = '''mkt-etl-failure-alert-aaaagteba5klfmdtvkwts3m4ca@chewy.org.slack.com'''
        self.NOTIFICATION_URL = 'https://9yjxsxeabk.execute-api.us-east-1.amazonaws.com/sbx/api/message/'


class DevelopmentConfig(Config):
    def __init__(self, config_options):
        super().__init__()
        self.snowflake_database = "EDLDB_DEV"
        self.SLACK_SUCCESS = '''mkt-etl-success-alert-aaaags6ughywknj64qawvq2qpy@chewy.org.slack.com'''
        self.SLACK_FAILURE = '''aukani@chewy.com'''    # '''mkt-etl-failure-alert-aaaagteba5klfmdtvkwts3m4ca@chewy.org.slack.com'''
        self.NOTIFICATION_URL = 'https://9yjxsxeabk.execute-api.us-east-1.amazonaws.com/sbx/api/message/'
        self.REC_LIST = ["DL-Digital-Marketing-Ops@chewy.com"]
        # Update and extend running options
        self.__dict__.update(config_options)
        self.snowflake_username = config_options["SNOW_USER"]
        self.snowflake_password = config_options["SNOW_PASS"]
        self.snowflake_account = config_options["SNOW_ACCOUNT"]

        # Email Dev
        if not self.REC_LIST:
            raise ValueError("Pass a recipient list for Email functions")
        if not isinstance(self.REC_LIST, list):
            raise ValueError(
                f"Recipient must be a list and passed is {type(self.REC_LIST)}"
            )

        if not self.snowflake_username or not self.snowflake_password:
            raise ValueError("Snowflake username or password are not set")

        self.snowflake_engine = create_engine(
            f"snowflake://{self.snowflake_username}:{self.snowflake_password}@{self.snowflake_account}/"
            f"{self.snowflake_database}&role={self.snowflake_role}"
        )


class ProductionConfig(Config):
    def __init__(self, config_options):
        super().__init__()
        self.snowflake_database = "EDLDB"
        self.SLACK_SUCCESS = '''mkt-etl-success-alert-aaaags6ughywknj64qawvq2qpy@chewy.org.slack.com'''
        self.SLACK_FAILURE = '''mkt-etl-failure-alert-aaaagteba5klfmdtvkwts3m4ca@chewy.org.slack.com'''
        self.NOTIFICATION_URL = 'https://9yjxsxeabk.execute-api.us-east-1.amazonaws.com/sbx/api/message/'

        # Update and extend running options
        self.REC_LIST = ["DL-Digital-Marketing-Ops@chewy.com"]
        self.__dict__.update(config_options)
        self.snowflake_username = config_options["SNOW_USER"]
        self.snowflake_password = config_options["SNOW_PASS"]
        self.snowflake_account = config_options["SNOW_ACCOUNT"]

        if not self.snowflake_username or not self.snowflake_password:
            raise ValueError("Snowflake username or password are not set")

        self.snowflake_engine = create_engine(
            f"snowflake://{self.snowflake_username}:{self.snowflake_password}@{self.snowflake_account}/"
            f"{self.snowflake_database}&role={self.snowflake_role}"
        )


config_hostname_map = {
    "development": DevelopmentConfig,
    "production": ProductionConfig,
    "default": DevelopmentConfig,
}


def configure(conf_options={}):
    """
    :params:
        :config_options (dict): configuration options to update the
            environment configuration
    """
    configuration = config_hostname_map.get(conf_options["env"])
    print(f"Running in {configuration} Env")
    config = configuration(config_options=conf_options)
    return config
