import boto3
import json


def get_secret(secret_name=None):
    session = boto3.session.Session()
    client = session.client(service_name='secretsmanager', region_name="us-east-1")
    """
    Args:
        secret_name: Secret Name assigned on Secrets Manager on AWS
    Returns:
        If running in prod, it looks for the json object within SecretsManager.
        Once local testing has been done, the secret key withing AWS must be updated.
    """
    # If Running in production
    # Create a Secrets Manager client
    try:
        get_secret_value_response = client.get_secret_value(
            SecretId=secret_name
        )
    except Exception as err:
        raise ValueError(err)
    else:
        # Decrypts secret using the associated KMS CMK.
        # Depending on whether the secret is a string or binary, one of these fields will be populated.
        if 'SecretString' in get_secret_value_response:
            secret = get_secret_value_response['SecretString']
            secret_json = json.loads(secret)
        else:
            decoded_binary_secret = base64.b64decode(get_secret_value_response['SecretBinary'])
            secret_json = json.loads(decoded_binary_secret)
        return secret_json
